package ch.epfl.ppo.adapters;

import java.awt.image.BufferedImage;

import ch.epfl.ppo.ColorRGB;
import ch.epfl.ppo.ImageRGB;

public final class DiscreteImageAdapter implements ImageRGB {
    private final ColorRGB backgroundColor;
    private final BufferedImage discreteImage;
    private final int w, h;

    public DiscreteImageAdapter(ColorRGB backgroundColor, BufferedImage discreteImage) {
        this.backgroundColor = backgroundColor;
        this.discreteImage = discreteImage;
        this.w = discreteImage.getWidth();
        this.h = discreteImage.getHeight();
    }

    @Override
    public ColorRGB valueAt(double x, double y) {
        double s = w / 2.0;
        int iX = (int)Math.round( x * s + w / 2.0);
        int iY = (int)Math.round(-y * s + h / 2.0);

        if (0 <= iX && iX < w && 0 <= iY && iY < h)
            return new ColorRGB(discreteImage.getRGB(iX, iY));
        else
            return backgroundColor;
    }
}
