package ch.epfl.ppo.generators;

import ch.epfl.ppo.ColorRGB;
import ch.epfl.ppo.ImageRGB;

public final class ChessboardGenerator implements ImageRGB {
    private final ColorRGB color1, color2;
    private final double squareSize;

    public ChessboardGenerator(ColorRGB color1, ColorRGB color2, double squareSize) {
        if (! (squareSize > 0.0))
            throw new IllegalArgumentException("illegal square size: " + squareSize);
        this.color1 = color1;
        this.color2 = color2;
        this.squareSize = squareSize;
    }

    @Override
    public ColorRGB valueAt(double x, double y) {
        double sqX = Math.floor(x / squareSize), sqY = Math.floor(y / squareSize);
        return ((int)(sqX + sqY)) % 2 == 0 ? color1 : color2;
    }
}
